@@ -71,7 +71,8 @@ class EnterpriseLearnerEnrollment(models.Model):
         verbose_name = _("Enterprise Learner Enrollment")
         verbose_name_plural = _("Enterprise Learner Enrollments")
 
-    enterprise_enrollment_id = models.PositiveIntegerField(primary_key=True)
+    primary_key = models.BigIntegerField(primary_key=True)
+    enterprise_enrollment_id = models.PositiveIntegerField(null=True)
     enrollment_id = models.PositiveIntegerField(null=True)
     is_consent_granted = models.BooleanField(default=False)
     paid_by = models.CharField(max_length=255, null=True)
